@@ -1,6 +1,6 @@
 package CGI::Application::Plugin::Session;
 {
-  $CGI::Application::Plugin::Session::VERSION = '1.04';
+  $CGI::Application::Plugin::Session::VERSION = '1.05';
 }
 
 use CGI::Session ();
@@ -190,6 +190,7 @@ sub session_delete {
 
     if ( my $session = $self->session ) {
         $session->delete;
+        $session->flush;
         if ( $self->{'__CAP__SESSION_CONFIG'}->{'SEND_COOKIE'} ) {
             my %options;
             if ( $self->{'__CAP__SESSION_CONFIG'}->{'COOKIE_PARAMS'} ) {
@@ -240,6 +241,7 @@ sub session_recreate {
     if (session_loaded($self)) {
         $data = $self->session->param_hashref;
         $self->session->delete;
+        $self->session->flush;
         $self->{__CAP__SESSION_OBJ} = undef;
 
     }
@@ -251,6 +253,7 @@ sub session_recreate {
         next if index($k, '_SESSION_') == 0;
         $session->param($k => $v);
     }
+    $session->flush;
 
     return 1;
 }
@@ -277,13 +280,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 CGI::Application::Plugin::Session - Plugin that adds session support to CGI::Application
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
